@@ -1,15 +1,19 @@
 from ..base import ExitCallInterceptor
 from pythonagent.agent.probes.Instrumentation.parser import create_method_array
 # from pythonagent.agent.probes.havoc.havoc_manager import NDNetHavocMonitor
+from pythonagent.utils import get_current_timestamp_in_ms
 
 import os
 import configparser
 import time
+import logging
+
+logger = logging.getLogger('pythonagent.agent')
 
 #configParser = configparser.RawConfigParser()
 path = os.environ.get('ND_HOME')
 path = path + '/config/ndsettings.conf'
-print("path of  NDC config : ",path)
+logger.info("path of  NDC config : ", path)
 #configParser.read(path)
 #path_for_insProfile = configParser.get('PYTHON_AGENT', 'path_profile')
 myvars = {}
@@ -24,17 +28,17 @@ try:
 except:
     #print("inside except")
     path_for_insProfile= os.environ.get('ND_HOME') + "/CavAgent/instrumentationprofile.json"
-print('Profiler path at : ',path_for_insProfile)
+logger.debug('Profiler path at : {}'.format(path_for_insProfile))
 #custom_methods_to_instrument = create_method_array('/home/cavisson/shop/my-shop/instrumentationprofile.txt')
 custom_methods_to_instrument = create_method_array(path_for_insProfile)
-print("ALL custom modules(Instrument)-> ", custom_methods_to_instrument)
+logger.debug("ALL custom modules(Instrument)-> ".format(custom_methods_to_instrument))
 
 
 class MethodInterceptor(ExitCallInterceptor):
 
     def _custom_method(self, original_method, *args, **kwargs):
 
-        print("\n\n\n\nInside Custom Method\n\n\n")
+        logger.info("\n\n\n\nInside Custom Method\n\n\n")
         bt = self.bt
 
         if len(self.cls.__package__) >= 1:
@@ -45,7 +49,8 @@ class MethodInterceptor(ExitCallInterceptor):
 
         # print("Inside custom method")
 
-        before_time = time.time_ns() // 1000000
+        #before_time = time.time_ns() // 1000000
+        before_time=get_current_timestamp_in_ms()
 
         # print("Before applying method call delay")
         # print("FQM: ", fqmforentry)
@@ -71,21 +76,22 @@ class MethodInterceptor(ExitCallInterceptor):
 
             finally:
 
-                after_time = time.time_ns() // 1000000
+                #after_time = time.time_ns() // 1000000
+                after_time = get_current_timestamp_in_ms()
                 duration = after_time - before_time
-                print("Duration Calculated: ", duration)
+                logger.info("Duration Calculated: {}".format(duration))
 
                 try:
                     havoc_monitor.apply_method_invocation_failure(fqmforentry)
                 except Exception as e:
                     if isinstance(e, NDHavocException):
-                        print("Havoc Exception {}".format(e))
+                        logger.error("Havoc Exception {}".format(e))
                         status = 503
                         self.agent.method_exit(bt, fqmforentry, status, duration)
                         self.agent.set_current_status_code(503)
                         raise e
                     else:
-                        print("Non-Havoc Exception {}".format(e))
+                        logger.error("Non-Havoc Exception {}".format(e))
 
                 status = 0  # Needed for callouts only
                 if self.agent.cav_env == "AWS_LAMBDA":
@@ -106,9 +112,9 @@ class MethodInterceptor(ExitCallInterceptor):
 
 
 def intercept_instrumented_method(agent, mod):
-    print("\n\n\n")
-    print("intercept instrumented method")
-    print("\n\n\n")
+    logger.info("\n\n\n")
+    logger.info("intercept instrumented method")
+    logger.info("\n\n\n")
 
     for item in custom_methods_to_instrument:
         #print("CUSTOM METHOD TO INSTRUMENT ", item)
